@@ -6,13 +6,13 @@ class FDBase:
     pins = []
 
     def check_param(self):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def reload(self):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def show(self):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def run(self):
         [setattr(self, k, v) for k, v in self.Parameters.items()]
