@@ -1,14 +1,14 @@
 import matplotlib.pyplot as plt
+
 from .base import FDBase
-from FDLib.lib.ploy import *
-from FDLib.utils import autoscale_axes
+from FDLib.lib._shape import Shape  # noqa
 
 __all__ = ["FDLibrary"]
 
 
 class FDLibrary(FDBase):
     def __init__(self):
-        self.specifications: list[Polygon] = []
+        self.specifications: list[Shape] = []
 
     def __repr__(self):
         inner = [repr(one) for one in self.specifications]
@@ -17,11 +17,12 @@ class FDLibrary(FDBase):
 
     def show(self):
         fig, axes = plt.subplots()
-        fig.set_size_inches(8, 8)
-        axes.set_title("Result")
+        axes.set_title(self.__class__.__name__)
         for one in self.specifications:
             one.draw_body(axes)
             one.draw_pins(axes)
             one.draw_net(axes)
-        autoscale_axes(axes)
+        axes.relim()
+        axes.autoscale_view()
+        axes.set_aspect("equal")
         plt.show()
